pub struct BlameLine {
pub oid: ObjectId,
pub final_lineno: usize,
pub orig_lineno: usize,
pub content: String,
pub source_file: Option<String>,
pub ignored: bool,
pub unblamable: bool,
pub external_contents: bool,
}Expand description
A single line attribution.
Fields
oid: ObjectIdfinal_lineno: usize1-based line number in the final file.
orig_lineno: usize1-based line number in the originating commit.
content: Stringsource_file: Option<String>Source filename (differs from target when -C detects a copy).
ignored: boolTrue when this line was forced through an ignored revision.
unblamable: boolTrue when this line could not be blamed past an ignored revision.
external_contents: boolLine comes from --contents and does not match the blamed revision (git: “External file”).