RefNameError

Enum RefNameError 

pub enum RefNameError {
Show 13 variants Empty, LoneAt, ComponentStartsDot, DoubleDot, IllegalChar, AtBrace, InvalidWildcard, DotLock, TrailingSlash, LeadingSlash, TrailingDot, OneLevel, ConsecutiveSlashes,
}
Errors returned by check_refname_format.

Variants



Empty

The ref name is empty.



LoneAt

The ref name is exactly @.



ComponentStartsDot

A component starts with ..



DoubleDot

The ref name contains ...



IllegalChar

An illegal character was found (control chars, space, ~, ^, :, ?, [, \\).



AtBrace

The ref name contains @{{.



InvalidWildcard

The ref name contains * but --refspec-pattern was not set, or contains more than one * with --refspec-pattern.



DotLock

A path component ends with .lock.



TrailingSlash

The ref name ends with /.



LeadingSlash

The ref name starts with / (after normalization).



TrailingDot

The ref name ends with ..



OneLevel

The ref name has only one component and --allow-onelevel was not set.



ConsecutiveSlashes

The ref name has zero-length components (consecutive slashes) that cannot be normalized away.