Human-oriented commit one-line formats shared by porcelain commands.
Functions
- abbrev_
hex - Abbreviate
oidto at mostabbrev_lenhex characters (minimum 4, maximum 40). - add_
indented_ text - Indent each line of
text(Git strbuf_add_indented_text): the first line byindent1spaces and subsequent lines byindent2. Used when wrap width is 0. - add_
wrapped_ text - Word-wrap
texttowidthcolumns with the same wrapping behavior as Git’sstrbuf_add_wrapped_text, used by the%w(width,indent1,indent2)pretty directive. - format_
reference_ line - One-line
referenceformat:abbrev (subject, YYYY-MM-DD). - format_
short_ date_ from_ ident - Format the author/committer date as
YYYY-MM-DDin the commit’s local timezone. - message_
body - Return the body slice after the first message paragraph.
- message_
subject - Return the pretty subject for a commit or tag message.