pub fn format_trailers(msg: &str, opts: &TrailerOpts) -> StringExpand description
Format the trailers of msg according to opts, matching Git’s
format_trailers_from_commit used by the %(trailers:...) pretty placeholder.
pub fn format_trailers(msg: &str, opts: &TrailerOpts) -> StringFormat the trailers of msg according to opts, matching Git’s
format_trailers_from_commit used by the %(trailers:...) pretty placeholder.