parse_bool

Function parse_bool 

pub fn parse_bool(s: &str) -> Result<bool, String>
Parse a Git boolean value.

Accepts: true, yes, on, 1 as true. Accepts: false, no, off, 0 (and explicit empty value) as false.

Note: bare config keys are represented as None in ConfigEntry and are normalized to "true" by higher-level readers (ConfigSet::get). This parser only sees string values and therefore treats "" as an explicitly empty assignment (key =), which Git interprets as false.