parse_path_optional

Function parse_path_optional 

pub fn parse_path_optional(s: &str) -> Option<String>
Parse a path value that may have an :(optional) prefix.

Returns Some(path) if the path should be used, None if the path is optional and does not exist (meaning the entry should be skipped).