Module delta_encode

Module delta_encode 

Encode Git pack binary deltas (format decoded by crate::unpack_objects::apply_delta).

Used when writing REF_DELTA pack objects so repositories can store similar blobs compactly (see git diff-delta / create_delta in upstream Git).

Functions

encode_prefix_extension_delta
Build a delta when target begins with the entire base buffer (strict extension).