pub fn submodule_git_dir_for_fetch(
super_repo: &Repository,
rel_path: &str,
) -> Option<PathBuf>Expand description
Open the git directory for a submodule at rel_path (work tree or .git/modules/ fallback).
pub fn submodule_git_dir_for_fetch(
super_repo: &Repository,
rel_path: &str,
) -> Option<PathBuf>Open the git directory for a submodule at rel_path (work tree or .git/modules/ fallback).