pub struct FmtMergeMsgOptions {
pub message: Option<String>,
pub into_name: Option<String>,
}Expand description
Options for fmt_merge_msg.
Fields
message: Option<String>Override the first line of the message with this text. When set, the branch-name title is suppressed.
into_name: Option<String>Override the target branch name shown in into <branch>.