pub struct CacheTreeNode {
pub name: Vec<u8>,
pub entry_count: i32,
pub oid: Option<ObjectId>,
pub children: Vec<CacheTreeNode>,
}Expand description
One node from Git’s TREE index extension.
Fields
name: Vec<u8>Path component for this node. The root node stores an empty name.
entry_count: i32Number of index entries covered by this node, or -1 when invalid.
oid: Option<ObjectId>Tree object ID for valid nodes. Invalid nodes do not store an object ID.
children: Vec<CacheTreeNode>Immediate child cache-tree nodes.
Implementations
Sourceimpl CacheTreeNode
impl CacheTreeNode
Sourcepub fn valid(
name: Vec<u8>,
entry_count: i32,
oid: ObjectId,
children: Vec<CacheTreeNode>,
) -> Self
pub fn valid( name: Vec<u8>, entry_count: i32, oid: ObjectId, children: Vec<CacheTreeNode>, ) -> Self
Create a valid cache-tree node.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Mark this node as invalid while preserving its children.