pub struct Options {
pub heads: bool,
pub tags: bool,
pub refs_only: bool,
pub symref: bool,
pub patterns: Vec<String>,
}Expand description
Options controlling which references ls_remote returns.
Fields
heads: boolRestrict output to refs/heads/ entries only.
Restrict output to refs/tags/ entries only.
refs_only: boolExclude pseudo-refs (HEAD) and peeled tag ^{} entries.
symref: boolAnnotate symbolic refs (HEAD) with their ref: <target> line.
patterns: Vec<String>If non-empty, only return refs matching one of these patterns.
A ref matches when it equals the pattern exactly or when its name
ends with /<pattern>.