pub fn read_notes_tree(
repo: &Repository,
notes_ref: &str,
) -> Result<Vec<NotesTreeEntry>>Expand description
Read the notes tree entries from the notes ref. Returns an empty vec if the ref doesn’t exist yet.
pub fn read_notes_tree(
repo: &Repository,
notes_ref: &str,
) -> Result<Vec<NotesTreeEntry>>Read the notes tree entries from the notes ref. Returns an empty vec if the ref doesn’t exist yet.