pub fn write_notes_commit(
repo: &Repository,
notes_ref: &str,
entries: &[NotesTreeEntry],
message: &str,
) -> Result<()>Expand description
Write a new notes tree and commit, updating the notes ref.
pub fn write_notes_commit(
repo: &Repository,
notes_ref: &str,
entries: &[NotesTreeEntry],
message: &str,
) -> Result<()>Write a new notes tree and commit, updating the notes ref.