PatchIdMode

Enum PatchIdMode 

pub enum PatchIdMode {
    Unstable,
    Stable,
    Verbatim,
}
How to compute a patch-ID from unified diff text.

Variants



Unstable

Accumulate file diffs into one rolling SHA-1; file order affects the result. Compatible with Git 1.9 and older. This is the default.



Stable

Hash each file’s diff independently and accumulate results with a carry-addition, so file order does not affect the patch-ID.



Verbatim

Like PatchIdMode::Stable but whitespace is not stripped before hashing.