resolve_pathspec

Function resolve_pathspec 

pub fn resolve_pathspec(
    pathspec: &str,
    work_tree: &Path,
    prefix: Option<&str>,
) -> String
Resolve a pathspec string to a path relative to the repository work tree.

prefix is the current directory relative to the work tree (no trailing slash), or None when cwd is the work tree root.