pub fn parse_fetch_refspec(refspec: &str) -> Result<RefspecItem, RefspecError>Expand description
Parse a fetch refspec, returning the parsed item or an error.
pub fn parse_fetch_refspec(refspec: &str) -> Result<RefspecItem, RefspecError>Parse a fetch refspec, returning the parsed item or an error.