pub fn parse_push_refspec(refspec: &str) -> Result<RefspecItem, RefspecError>Expand description
Parse a push refspec, returning the parsed item or an error.
pub fn parse_push_refspec(refspec: &str) -> Result<RefspecItem, RefspecError>Parse a push refspec, returning the parsed item or an error.