verify_commit

Function verify_commit 

pub fn verify_commit(
    cfg: &GpgConfig,
    raw_commit: &[u8],
) -> Result<SignatureCheck>
Verify a raw commit object’s embedded signature.

Extracts the payload + signature, then (for gpg-based formats) writes the signature to a temp file and runs <program> --status-fd=1 <verify_args> --verify <sigfile> -, feeding the payload on stdin, and parses the [GNUPG:] status lines.