Module submodule_active

Module submodule_active 

Submodule “active” state (submodule.c is_submodule_active parity).

Used by test-tool submodule is-active and git submodule add when deciding whether to write submodule.<name>.active.

Functions

is_submodule_active
Git is_submodule_active for the current repository and index (HEAD + .gitmodules mapping).
submodule_active_pathspec_match
Whether path matches submodule.active pathspecs using the given index (Git match_pathspec).
submodule_add_should_set_active
Whether git submodule add should write submodule.<name>.active=true to the local config.
submodule_name_for_path
Resolve the submodule logical name for an index path (.gitmodules submodule.<name>.path).