path_inside_registered_submodule_name

Function path_inside_registered_submodule_name 

pub fn path_inside_registered_submodule_name(
    work_tree: &Path,
    new_path: &str,
) -> bool
True when new_path is the same as or nested under a .gitmodules submodule name (the submodule.<name>.* section name), which may contain /.

Git rejects such paths when submodulePathConfig is off (die_path_inside_submodule on logical names). When the extension is enabled, encoded gitdirs lift this restriction.