GitDaemonConnection

Struct GitDaemonConnection 

pub struct GitDaemonConnection { /* private fields */ }
A live connection to a Git daemon over a duplex TCP socket.

Holds the read and write halves of the socket (duplicated file descriptors of the same connection) plus the advertisement read on connect.