write_tree_from_index_subset

Function write_tree_from_index_subset 

pub fn write_tree_from_index_subset(
    odb: &Odb,
    index: &Index,
    paths: &HashSet<Vec<u8>>,
) -> Result<ObjectId>
Build and write tree object(s) from index entries and return the tree OID.

The prefix argument optionally limits the write to a subtree path. Like write_tree_from_index, but only index entries whose path is listed in paths (repository-relative, as stored in the index) are included in the tree.