pub fn load_gitattributes_stack(
repo: &Repository,
work_tree: &Path,
) -> Result<ParsedGitAttributes, Error>Expand description
Load the full stack of attribute rules for a normal repository (working tree).
pub fn load_gitattributes_stack(
repo: &Repository,
work_tree: &Path,
) -> Result<ParsedGitAttributes, Error>Load the full stack of attribute rules for a normal repository (working tree).