CombinedParentStatus

Enum CombinedParentStatus 

pub enum CombinedParentStatus {
    Added,
    Modified,
    Deleted,
}
Per-parent coarse status in a combined diff (A / M / D).

Variants



Added

Parent lacks the path; merge tree added it.



Modified

Parent has the path at the same name as the merge result.



Deleted

Path removed from merge (only in parents that had it at the min name).