Module commit_pretty

Module commit_pretty 

Human-oriented commit one-line formats shared by porcelain commands.

Functions

abbrev_hex
Abbreviate oid to at most abbrev_len hex characters (minimum 4, maximum 40).
add_indented_text
Indent each line of text (Git strbuf_add_indented_text): the first line by indent1 spaces and subsequent lines by indent2. Used when wrap width is 0.
add_wrapped_text
Word-wrap text to width columns, a faithful port of Git’s strbuf_add_wrapped_text (utf8.c), used by the %w(width,indent1,indent2) pretty directive.
format_reference_line
One-line reference format: abbrev (subject, YYYY-MM-DD).
format_short_date_from_ident
Format the author/committer date as YYYY-MM-DD in the commit’s local timezone.
message_body
Return the body slice after the first message paragraph.
message_subject
Return the pretty subject for a commit or tag message.