pub fn message_subject(message: &str) -> StringExpand description
Return the pretty subject for a commit or tag message.
The subject is the first non-empty paragraph with embedded line breaks collapsed to spaces. Both LF and CRLF line endings are recognized.
Parameters
message— raw commit or tag message text.