pub fn push_tip_objects_exist(repo: &Repository, tip: ObjectId) -> Result<bool>Expand description
Verifies that every object reachable from tip exists in repo.odb.
Errors
Returns Error::CorruptObject when tip is not a commit or tree data is invalid.