pub fn diff_attr_forces_text(git_dir: &Path, path: &str) -> bool
True when a path carries a bare diff (set) attribute, which forces Git to produce a textual diff even when the blob contains NUL bytes (t4020 #65).
diff