pub fn parse_tree_with_oid_len(
data: &[u8],
oid_len: usize,
) -> Result<Vec<TreeEntry>>Expand description
Parse a tree blob assuming a fixed raw OID width (oid_len bytes).
Returns an error if the data does not parse cleanly into whole entries of
that width (used by parse_tree to detect the hash algorithm).