pub fn serialize_tree(entries: &[TreeEntry]) -> Vec<u8> ⓘ
Build the raw bytes of a tree object from a slice of entries.
Entries must already be sorted in Git tree order (see tree_entry_cmp) before calling this function.
tree_entry_cmp