pub fn compute_patch_id_for_paths(
odb: &Odb,
commit_oid: &ObjectId,
paths: &[String],
) -> Result<Option<ObjectId>>Expand description
Compute the patch-ID for a single commit, limited to matching pathspecs.
This follows compute_patch_id semantics, but ignores file diffs whose
old and new paths do not match paths.
Parameters
odb— object database used to read commit, tree, and blob objects.commit_oid— OID of the commit to compute the patch-ID for.paths— pathspec strings used to limit the files included in the diff.
Errors
Returns errors from object-database reads or object-parse failures.