pub fn resolve_magic_pathspec(spec: &str, cwd_prefix: &str) -> Option<String>Expand description
Resolve a magic pathspec relative to a current-directory prefix.
This keeps the cwd prefix case-sensitive (via an internal prefix: magic
token) while still honoring magic options like icase for the tail.
Returns None when spec is not a parseable magic pathspec.