Protocol allow/deny policy.
Implements the protocol.<name>.allow config and GIT_ALLOW_PROTOCOL
environment semantics without reading process-global state directly.
Structs
- Client
Protocol Version Inputs - Explicit inputs for selecting the client-side Git wire protocol version.
- Protocol
Policy Inputs - Explicit inputs for protocol allow/deny evaluation.
Enums
- Protocol
Error - Errors returned when a transport protocol is not allowed.
Functions
- check_
protocol_ allowed_ with - Check whether a given protocol (e.g.
file,git,ssh,https) is allowed. - effective_
client_ protocol_ version_ from_ inputs - Select the effective client-side protocol version.
- merged_
git_ protocol_ value - Merge a requested client protocol version into an existing
GIT_PROTOCOLvalue. - parse_
protocol_ version_ digit - Parse a protocol version digit (
0,1, or2). - protocol_
from_ user - Whether
protocol.<name>.allow=usershould be considered allowed. - server_
protocol_ version_ from_ git_ protocol - Server-side protocol version: highest
version=NfromGIT_PROTOCOL, or0if unset.