pub fn merged_git_protocol_value(
client_wants: u8,
existing: Option<&str>,
) -> Option<String>Expand description
Merge a requested client protocol version into an existing GIT_PROTOCOL value.
Existing version=N entries are removed before appending the requested version.
Returns None when client_wants is 0.