PushRefStatus

Enum PushRefStatus 

pub enum PushRefStatus {
    UpToDate,
    Ok,
    RejectNonFastForward,
    RejectAlreadyExists,
    RejectFetchFirst,
    RejectNeedsForce,
    RejectStale,
    RemoteRejected,
    AtomicPushFailed,
}
The resolved outcome of a single reference update during a push.

Variants



UpToDate

The reference was already at the requested value (=, [up to date]).



Ok

A successful update (* new, - delete, fast-forward, + forced).



RejectNonFastForward

Client-side rejection: the update is not a fast-forward and --force was not given (!, [rejected] (non-fast-forward)).



RejectAlreadyExists

Rejected because the new ref already exists (!, [rejected] (already exists)).



RejectFetchFirst

Rejected because the remote has the ref but we need to fetch first.



RejectNeedsForce

Rejected because a forced update is required.



RejectStale

Rejected because force-with-lease found stale info.



RemoteRejected

The remote receive-pack declined the update (!, [remote rejected] (<reason>)).



AtomicPushFailed

Part of an atomic push that failed because another ref was rejected (!, [rejected] (atomic push failed)).

Implementations

Source

impl PushRefStatus

pub fn is_error(&self) -> bool

Whether this status represents a hard failure (causes a non-zero exit).