pub enum RefnameUnavailable {
AncestorExists {
blocking: String,
new_ref: String,
},
DescendantExists {
blocking: String,
new_ref: String,
},
SameBatch {
refname: String,
other: String,
},
}Expand description
Why a reference name cannot be created (Git refs_verify_refname_available style).
Variants
AncestorExists
An ancestor ref already exists in the store (e.g. refs/foo blocks refs/foo/bar).
Fields
DescendantExists
A descendant ref already exists (e.g. refs/foo/bar blocks refs/foo).
SameBatch
Two refnames in the same batch are mutually incompatible (parent vs child).
Implementations
Sourcepub fn lock_message_suffix(&self) -> String
pub fn lock_message_suffix(&self) -> String
Suffix after cannot lock ref '<display_ref>': for stderr (no trailing newline).