RevListOptions

Struct RevListOptions 

pub struct RevListOptions {
Show 40 fields pub all_refs: bool, pub first_parent: bool, pub ancestry_path: bool, pub ancestry_path_bottoms: Vec<ObjectId>, pub simplify_by_decoration: bool, pub output_mode: OutputMode, pub quiet: bool, pub count: bool, pub skip: usize, pub max_count: Option<usize>, pub ordering: OrderingMode, pub reverse: bool, pub objects: bool, pub no_object_names: bool, pub boundary: bool, pub left_right: bool, pub left_only: bool, pub right_only: bool, pub cherry_mark: bool, pub cherry_pick: bool, pub min_parents: Option<usize>, pub max_parents: Option<usize>, pub symmetric_left: Option<ObjectId>, pub symmetric_right: Option<ObjectId>, pub paths: Vec<String>, pub full_history: bool, pub sparse: bool, pub filter: Option<ObjectFilter>, pub filter_provided_objects: bool, pub filter_print_omitted: bool, pub in_commit_order: bool, pub no_kept_objects: bool, pub missing_action: MissingAction, pub use_bitmap_index: bool, pub unpacked_only: bool, pub bitmap_oid_only_objects: bool, pub until_cutoff: Option<i64>, pub since_cutoff: Option<i64>, pub include_reflog_entries: bool, pub include_indexed_objects: bool,
}
Parsed and normalized options for rev-list traversal.

Fields

all_refs: bool

Include all refs (--all) as positive tips.

first_parent: bool

Follow only first parent when walking merges.

ancestry_path: bool

Enable ancestry-path filtering.

ancestry_path_bottoms: Vec<ObjectId>

Optional explicit ancestry-path pivot commits.

simplify_by_decoration: bool

Keep only decorated commits after traversal.

output_mode: OutputMode

Commit output mode.

quiet: bool

Suppress commit output.

count: bool

Print only final count.

skip: usize

Skip N commits from selected list.

max_count: Option<usize>

Optional maximum selected commits.

ordering: OrderingMode

Ordering strategy.

reverse: bool

Reverse selected output order.

objects: bool

List reachable objects (trees, blobs) in addition to commits.

no_object_names: bool

Suppress object path names in –objects output.

boundary: bool

Show boundary commits with - prefix.

left_right: bool

Show left/right markers for symmetric diff.

left_only: bool

Filter to left-only commits in symmetric diff.

right_only: bool

Filter to right-only commits in symmetric diff.

cherry_mark: bool

Cherry-mark equivalent commits with = instead of +.

cherry_pick: bool

Cherry-pick: omit equivalent commits from output.

min_parents: Option<usize>

Minimum number of parents a commit must have to be included.

max_parents: Option<usize>

Maximum number of parents a commit may have to be included.

symmetric_left: Option<ObjectId>

Symmetric-diff left OID (set by caller when A…B is used).

symmetric_right: Option<ObjectId>

Symmetric-diff right OID (set by caller when A…B is used).

paths: Vec<String>

Path filters (files after --).

full_history: bool

Show full history (don’t simplify) for path-limited walks.

sparse: bool

Sparse mode: don’t prune non-matching commits.

filter: Option<ObjectFilter>

Object filter for --filter=<spec>.

filter_provided_objects: bool

When set with --filter, explicitly given revision objects are filtered too.

filter_print_omitted: bool

Print omitted objects prefixed with ~.

in_commit_order: bool

Emit objects interleaved with their introducing commit.

no_kept_objects: bool

Exclude objects in .keep pack files.

missing_action: MissingAction

Behavior when referenced objects are missing.

use_bitmap_index: bool

When set with --objects, omit path names from non-commit object lines (bitmap-style output).

unpacked_only: bool

When set with --objects, list only objects not present in any pack file.

bitmap_oid_only_objects: bool

With --use-bitmap-index, emit OID-only object lines (no paths / trailing space) for filters that match Git’s bitmap object formatting.

until_cutoff: Option<i64>

Exclude commits with committer date strictly after this Unix timestamp (--until / --before).

since_cutoff: Option<i64>

Exclude commits with committer date strictly before this Unix timestamp (--since / --after).

include_reflog_entries: bool

Include OIDs from all reflogs as extra commit tips (git pack-objects --reflog).

include_indexed_objects: bool

Include blob OIDs from the index as object roots (git pack-objects --indexed-objects).