pub fn submodule_name_for_path(
repo: &Repository,
path: &str,
) -> Result<Option<String>>Expand description
Resolve the submodule logical name for an index path (.gitmodules submodule.<name>.path).
Returns None when the path is not listed as a submodule in .gitmodules (work tree file or
index blob), matching Git’s submodule_from_path failure.